diff --git a/common/frame.c b/common/frame.c
index 1d5ef24..b597ca1 100644
--- a/common/frame.c
+++ b/common/frame.c
@@ -297,7 +297,7 @@ void x264_frame_expand_border_mod16( x264_t *h, x264_frame_t *frame )
 
 /* cavlc + 8x8 transform stores nnz per 16 coeffs for the purpose of
  * entropy coding, but per 64 coeffs for the purpose of deblocking */
-void munge_cavlc_nnz_row( x264_t *h, int mb_y, uint8_t (*buf)[16] )
+static void munge_cavlc_nnz_row( x264_t *h, int mb_y, uint8_t (*buf)[16] )
 {
     uint32_t (*src)[6] = (uint32_t(*)[6])h->mb.non_zero_count + mb_y * h->sps->i_mb_width;
     int8_t *transform = h->mb.mb_transform_size + mb_y * h->sps->i_mb_width;
@@ -748,12 +748,12 @@ void x264_deblock_v8_luma_mmxext( uint8_t *pix, int stride, int alpha, int beta,
 void x264_deblock_h_luma_intra_mmxext( uint8_t *pix, int stride, int alpha, int beta );
 void x264_deblock_v8_luma_intra_mmxext( uint8_t *pix, int stride, int alpha, int beta );
 
-void x264_deblock_v_luma_mmxext( uint8_t *pix, int stride, int alpha, int beta, int8_t *tc0 )
+static void x264_deblock_v_luma_mmxext( uint8_t *pix, int stride, int alpha, int beta, int8_t *tc0 )
 {
     x264_deblock_v8_luma_mmxext( pix,   stride, alpha, beta, tc0   );
     x264_deblock_v8_luma_mmxext( pix+8, stride, alpha, beta, tc0+2 );
 }
-void x264_deblock_v_luma_intra_mmxext( uint8_t *pix, int stride, int alpha, int beta )
+static void x264_deblock_v_luma_intra_mmxext( uint8_t *pix, int stride, int alpha, int beta )
 {
     x264_deblock_v8_luma_intra_mmxext( pix,   stride, alpha, beta );
     x264_deblock_v8_luma_intra_mmxext( pix+8, stride, alpha, beta );
diff --git a/common/quant.c b/common/quant.c
index deeaf6c..ae5f69d 100644
--- a/common/quant.c
+++ b/common/quant.c
@@ -194,7 +194,7 @@ void x264_mb_dequant_4x4_dc( int16_t dct[4][4], int dequant_mf[6][4][4], int i_q
     }
 }
 
-void x264_denoise_dct_core( int16_t *dct, uint32_t *sum, uint16_t *offset, int size )
+static void x264_denoise_dct_core( int16_t *dct, uint32_t *sum, uint16_t *offset, int size )
 {
     int i;
     for( i=1; i<size; i++ )
diff --git a/common/set.c b/common/set.c
index df1c2de..a8e40bc 100644
--- a/common/set.c
+++ b/common/set.c
@@ -195,7 +195,7 @@ void x264_cqm_delete( x264_t *h )
     }
 }
 
-int x264_cqm_parse_jmlist( x264_t *h, const char *buf, const char *name,
+static int x264_cqm_parse_jmlist( x264_t *h, const char *buf, const char *name,
                            uint8_t *cqm, const uint8_t *jvt, int length )
 {
     char *p;
diff --git a/common/x86/mc-c.c b/common/x86/mc-c.c
index 0b76a41..c6e6958 100644
--- a/common/x86/mc-c.c
+++ b/common/x86/mc-c.c
@@ -87,7 +87,7 @@ PIXEL_AVG_WALL(cache64_sse2)
 PIXEL_AVG_WALL(sse2)
 
 #define AVG_WEIGHT(W,H,name) \
-void x264_pixel_avg_weight_ ## W ## x ## H ## _##name( uint8_t *dst, int i_dst, uint8_t *src, int i_src, int i_weight_dst ) \
+static void x264_pixel_avg_weight_ ## W ## x ## H ## _##name( uint8_t *dst, int i_dst, uint8_t *src, int i_src, int i_weight_dst ) \
 { \
     x264_pixel_avg_weight_w ## W ## _##name( dst, i_dst, src, i_src, i_weight_dst, H ); \
 }
@@ -143,7 +143,7 @@ static const int hpel_ref0[16] = {0,1,1,1,0,1,1,1,2,3,3,3,0,1,1,1};
 static const int hpel_ref1[16] = {0,0,0,0,2,2,3,2,2,2,3,2,2,2,3,2};
 
 #define MC_LUMA(name,instr1,instr2)\
-void mc_luma_##name( uint8_t *dst,    int i_dst_stride,\
+static void mc_luma_##name( uint8_t *dst,    int i_dst_stride,\
                   uint8_t *src[4], int i_src_stride,\
                   int mvx, int mvy,\
                   int i_width, int i_height )\
@@ -174,7 +174,7 @@ MC_LUMA(sse2,sse2,sse2)
 MC_LUMA(cache64_sse2,cache64_sse2,sse2)
 
 #define GET_REF(name)\
-uint8_t *get_ref_##name( uint8_t *dst,   int *i_dst_stride,\
+static uint8_t *get_ref_##name( uint8_t *dst,   int *i_dst_stride,\
                          uint8_t *src[4], int i_src_stride,\
                          int mvx, int mvy,\
                          int i_width, int i_height )\
@@ -210,7 +210,7 @@ void x264_hpel_filter_v_##cpuv( uint8_t *dst, uint8_t *src, int16_t *buf, int st
 void x264_hpel_filter_c_##cpuc( uint8_t *dst, int16_t *buf, int width );\
 void x264_hpel_filter_h_##cpuh( uint8_t *dst, uint8_t *src, int width );\
 void x264_sfence( void );\
-void x264_hpel_filter_##cpu( uint8_t *dsth, uint8_t *dstv, uint8_t *dstc, uint8_t *src,\
+static void x264_hpel_filter_##cpu( uint8_t *dsth, uint8_t *dstv, uint8_t *dstc, uint8_t *src,\
                              int stride, int width, int height )\
 {\
     int16_t *buf;\
diff --git a/encoder/macroblock.c b/encoder/macroblock.c
index 7d989a0..aedd1ba 100644
--- a/encoder/macroblock.c
+++ b/encoder/macroblock.c
@@ -289,7 +289,7 @@ static void x264_macroblock_encode_skip( x264_t *h )
  * x264_macroblock_encode_pskip:
  *  Encode an already marked skip block
  *****************************************************************************/
-void x264_macroblock_encode_pskip( x264_t *h )
+static void x264_macroblock_encode_pskip( x264_t *h )
 {
     const int mvx = x264_clip3( h->mb.cache.mv[0][x264_scan8[0]][0],
                                 h->mb.mv_min[0], h->mb.mv_max[0] );
diff --git a/encoder/ratecontrol.c b/encoder/ratecontrol.c
index 10f4df0..9f0b148 100644
--- a/encoder/ratecontrol.c
+++ b/encoder/ratecontrol.c
@@ -214,7 +214,7 @@ static NOINLINE int ac_energy_mb( x264_t *h, int mb_x, int mb_y, int *satd )
     return var;
 }
 
-void x264_autosense_aq( x264_t *h )
+static void x264_autosense_aq( x264_t *h )
 {
     double total = 0;
     double n = 0;
@@ -673,7 +673,7 @@ static int parse_zones( x264_t *h )
     return 0;
 }
 
-x264_zone_t *get_zone( x264_t *h, int frame_num )
+static x264_zone_t *get_zone( x264_t *h, int frame_num )
 {
     int i;
     for( i = h->rc->i_zones-1; i >= 0; i-- )
@@ -860,7 +860,7 @@ void x264_ratecontrol_start( x264_t *h, int i_force_qp )
         x264_autosense_aq(h);
 }
 
-double predict_row_size( x264_t *h, int y, int qp )
+static double predict_row_size( x264_t *h, int y, int qp )
 {
     /* average between two predictors:
      * absolute SATD, and scaled bit cost of the colocated row in the previous frame */
@@ -880,7 +880,7 @@ double predict_row_size( x264_t *h, int y, int qp )
     return (pred_s + pred_t) / 2;
 }
 
-double row_bits_so_far( x264_t *h, int y )
+static double row_bits_so_far( x264_t *h, int y )
 {
     int i;
     double bits = 0;
@@ -889,7 +889,7 @@ double row_bits_so_far( x264_t *h, int y )
     return bits;
 }
 
-double predict_row_size_sum( x264_t *h, int y, int qp )
+static double predict_row_size_sum( x264_t *h, int y, int qp )
 {
     int i;
     double bits = row_bits_so_far(h, y);
diff --git a/encoder/rdo.c b/encoder/rdo.c
index 76bf57b..7af702b 100644
--- a/encoder/rdo.c
+++ b/encoder/rdo.c
@@ -138,7 +138,7 @@ int x264_rd_cost_part( x264_t *h, int i_lambda2, int i8, int i_pixel )
     return i_ssd + i_bits;
 }
 
-int x264_rd_cost_i8x8( x264_t *h, int i_lambda2, int i8, int i_mode )
+static int x264_rd_cost_i8x8( x264_t *h, int i_lambda2, int i8, int i_mode )
 {
     int i_ssd, i_bits;
 
@@ -160,7 +160,7 @@ int x264_rd_cost_i8x8( x264_t *h, int i_lambda2, int i8, int i_mode )
     return i_ssd + i_bits;
 }
 
-int x264_rd_cost_i4x4( x264_t *h, int i_lambda2, int i4, int i_mode )
+static int x264_rd_cost_i4x4( x264_t *h, int i_lambda2, int i4, int i_mode )
 {
     int i_ssd, i_bits;
 
@@ -182,7 +182,7 @@ int x264_rd_cost_i4x4( x264_t *h, int i_lambda2, int i4, int i_mode )
     return i_ssd + i_bits;
 }
 
-int x264_rd_cost_i8x8_chroma( x264_t *h, int i_lambda2, int i_mode, int b_dct )
+static int x264_rd_cost_i8x8_chroma( x264_t *h, int i_lambda2, int i_mode, int b_dct )
 {
     int i_ssd, i_bits;
 
diff --git a/encoder/slicetype.c b/encoder/slicetype.c
index 1777100..84fabfe 100644
--- a/encoder/slicetype.c
+++ b/encoder/slicetype.c
@@ -37,7 +37,7 @@ static void x264_lowres_context_init( x264_t *h, x264_mb_analysis_t *a )
     h->mb.b_chroma_me = 0;
 }
 
-int x264_slicetype_mb_cost( x264_t *h, x264_mb_analysis_t *a,
+static int x264_slicetype_mb_cost( x264_t *h, x264_mb_analysis_t *a,
                             x264_frame_t **frames, int p0, int p1, int b,
                             int dist_scale_factor )
 {
@@ -238,7 +238,7 @@ lowres_intra_mb:
 #undef TRY_BIDIR
 #undef SAVE_MVS
 
-int x264_slicetype_frame_cost( x264_t *h, x264_mb_analysis_t *a,
+static int x264_slicetype_frame_cost( x264_t *h, x264_mb_analysis_t *a,
                                x264_frame_t **frames, int p0, int p1, int b,
                                int b_intra_penalty )
 {
@@ -353,7 +353,7 @@ static int scenecut( x264_t *h, x264_frame_t *frame, int pdist )
     return res;
 }
 
-void x264_slicetype_analyse( x264_t *h )
+static void x264_slicetype_analyse( x264_t *h )
 {
     x264_mb_analysis_t a;
     x264_frame_t *frames[X264_BFRAME_MAX+3] = { NULL, };
diff --git a/matroska.c b/matroska.c
index b3029c6..35ae4cd 100644
--- a/matroska.c
+++ b/matroska.c
@@ -407,7 +407,7 @@ static int mk_closeCluster(mk_Writer *w) {
   return 0;
 }
 
-int	  mk_flushFrame(mk_Writer *w) {
+static int mk_flushFrame(mk_Writer *w) {
   int64_t	delta, ref = 0;
   unsigned	fsize, bgsize;
   unsigned char	c_delta_flags[3];
diff --git a/muxers.c b/muxers.c
index bb2643c..3325515 100644
--- a/muxers.c
+++ b/muxers.c
@@ -459,7 +459,7 @@ int get_frame_total_thread( hnd_t handle )
     return h->frame_total;
 }
 
-void read_frame_thread_int( thread_input_arg_t *i )
+static void read_frame_thread_int( thread_input_arg_t *i )
 {
     i->status = i->h->p_read_frame( i->pic, i->h->p_handle, i->i_frame );
 }
@@ -806,7 +806,7 @@ typedef struct
     char      b_writing_frame;
 } mkv_t;
 
-int write_header_mkv( mkv_t *p_mkv )
+static int write_header_mkv( mkv_t *p_mkv )
 {
     int       ret;
     uint8_t   *avcC;
